==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QTextEncoder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(textcodec)
#include <QtCore/qtextcodec.h>
#endif //QT_CONFIG(textcodec)
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(textcodec)


void deleter_QTextEncoder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextEncoder")
    QTextEncoder *_ptr = reinterpret_cast<QTextEncoder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(textcodec)

// emitting (writeConstructors)
// new QTextEncoder(const QTextCodec*)
void __qt_construct_QTextEncoder_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextEncoder(const QTextCodec*)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    QTextEncoder *__qt_this = new(__qtjambi_ptr) QTextEncoder(__qt_codec0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// new QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)
void __qt_construct_QTextEncoder_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    jobject flags1 = __java_arguments[1].l;
    QTextCodec::ConversionFlags __qt_flags1 = qtjambi_cast<QTextCodec::ConversionFlags>(__jni_env, flags1);
    QTextEncoder *__qt_this = new(__qtjambi_ptr) QTextEncoder(__qt_codec0, QTextCodec::ConversionFlags(__qt_flags1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// destruct QTextEncoder
void __qt_destruct_QTextEncoder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextEncoder")

#if QT_CONFIG(textcodec)

    reinterpret_cast<QTextEncoder*>(ptr)->~QTextEncoder();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(textcodec)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextEncoder::QTextEncoder(const QTextCodec*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_initialize_1native__Lio_qt_core_QTextEncoder_2Lio_qt_core_QTextCodec_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextEncoder::QTextEncoder(const QTextCodec*)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments;
        arguments.l = codec0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextEncoder_0, sizeof(QTextEncoder), typeid(QTextEncoder), false, &deleter_QTextEncoder, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextEncoder::QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_initialize_1native__Lio_qt_core_QTextEncoder_2Lio_qt_core_QTextCodec_2Lio_qt_core_QTextCodec_00024ConversionFlags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextEncoder::QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments[2];
        arguments[0].l = codec0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextEncoder_1, sizeof(QTextEncoder), typeid(QTextEncoder), false, &deleter_QTextEncoder, arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        Q_UNUSED(flags1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextEncoder::fromUnicode(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_fromUnicode_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring str0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextEncoder::fromUnicode(QString)", __qt_this)
        QString  __qt_str0 = qtjambi_cast<QString >(__jni_env, str0);
        QByteArray __qt_return_value = __qt_this->fromUnicode(__qt_str0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(str0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextEncoder::hasFailure()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_hasFailure_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        const QTextEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextEncoder::hasFailure()const", __qt_this)
        __java_return_value = __qt_this->hasFailure();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextEncoder(){
    using namespace RegistryAPI;

#if QT_CONFIG(textcodec)

    const std::type_info& typeId = registerObjectTypeInfo<QTextEncoder>("QTextEncoder", "io/qt/core/QTextEncoder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextEncoder, {
        ConstructorInfo(&__qt_construct_QTextEncoder_0, "Lio/qt/core/QTextCodec;")
       ,ConstructorInfo(&__qt_construct_QTextEncoder_1, "Lio/qt/core/QTextCodec;Lio/qt/core/QTextCodec$ConversionFlags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextEncoder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(textcodec)

}

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QTextEncoder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(textcodec)
#include <QtCore/qtextcodec.h>
#endif //QT_CONFIG(textcodec)
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(textcodec)


void deleter_QTextEncoder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextEncoder")
    QTextEncoder *_ptr = reinterpret_cast<QTextEncoder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(textcodec)

// emitting (writeConstructors)
// new QTextEncoder(const QTextCodec*)
void __qt_construct_QTextEncoder_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextEncoder(const QTextCodec*)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    QTextEncoder *__qt_this = new(__qtjambi_ptr) QTextEncoder(__qt_codec0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// new QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)
void __qt_construct_QTextEncoder_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    jobject flags1 = __java_arguments[1].l;
    QTextCodec::ConversionFlags __qt_flags1 = qtjambi_cast<QTextCodec::ConversionFlags>(__jni_env, flags1);
    QTextEncoder *__qt_this = new(__qtjambi_ptr) QTextEncoder(__qt_codec0, QTextCodec::ConversionFlags(__qt_flags1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// destruct QTextEncoder
void __qt_destruct_QTextEncoder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextEncoder")

#if QT_CONFIG(textcodec)

    reinterpret_cast<QTextEncoder*>(ptr)->~QTextEncoder();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(textcodec)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextEncoder::QTextEncoder(const QTextCodec*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_initialize_1native__Lio_qt_core_QTextEncoder_2Lio_qt_core_QTextCodec_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextEncoder::QTextEncoder(const QTextCodec*)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments;
        arguments.l = codec0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextEncoder_0, sizeof(QTextEncoder), typeid(QTextEncoder), false, &deleter_QTextEncoder, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextEncoder::QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_initialize_1native__Lio_qt_core_QTextEncoder_2Lio_qt_core_QTextCodec_2Lio_qt_core_QTextCodec_00024ConversionFlags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextEncoder::QTextEncoder(const QTextCodec*,QTextCodec::ConversionFlags)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments[2];
        arguments[0].l = codec0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextEncoder_1, sizeof(QTextEncoder), typeid(QTextEncoder), false, &deleter_QTextEncoder, arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        Q_UNUSED(flags1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextEncoder::fromUnicode(QStringView)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_fromUnicode_1native_1QStringView__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring str0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__qtjambi_scope)
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextEncoder::fromUnicode(QStringView)", __qt_this)
        QStringView  __qt_str0 = qtjambi_cast<QStringView>(__jni_env, __qtjambi_scope, str0);
        QByteArray __qt_return_value = __qt_this->fromUnicode(__qt_str0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(str0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextEncoder::fromUnicode(const QChar*,int)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_fromUnicode_1native_1const_1QChar_1ptr_1int__JLjava_nio_CharBuffer_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject uc0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextEncoder::fromUnicode(const QChar*,int)", __qt_this)
        int len1{0};
        JBufferConstData __qt_uc0_buffer(__jni_env, uc0);
        const QChar* __qt_uc0 = __qt_uc0_buffer.data<QChar>();
        len1 = __qt_uc0_buffer.size<QChar>();
        QByteArray __qt_return_value = __qt_this->fromUnicode(__qt_uc0, static_cast<int>(len1));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(uc0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextEncoder::hasFailure()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextEncoder_hasFailure_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        const QTextEncoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextEncoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextEncoder::hasFailure()const", __qt_this)
        __java_return_value = __qt_this->hasFailure();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextEncoder(){
    using namespace RegistryAPI;

#if QT_CONFIG(textcodec)

    const std::type_info& typeId = registerObjectTypeInfo<QTextEncoder>("QTextEncoder", "io/qt/core/QTextEncoder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextEncoder, {
        ConstructorInfo(&__qt_construct_QTextEncoder_0, "Lio/qt/core/QTextCodec;")
       ,ConstructorInfo(&__qt_construct_QTextEncoder_1, "Lio/qt/core/QTextCodec;Lio/qt/core/QTextCodec$ConversionFlags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextEncoder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(textcodec)

}
